@@ -1,22 +1,20 @@
 /*
+ *  This file is part of XForms.
  *
- * This file is part of XForms.
+ *  XForms is free software; you can redistribute it and/or modify it
+ *  under the terms of the GNU Lesser General Public License as
+ *  published by the Free Software Foundation; either version 2.1, or
+ *  (at your option) any later version.
  *
- * XForms is free software; you can redistribute it and/or modify it
- * under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation; either version 2.1, or
- * (at your option) any later version.
- *
- * XForms is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with XForms; see the file COPYING.  If not, write to
- * the Free Software Foundation, 59 Temple Place - Suite 330, Boston,
- * MA 02111-1307, USA.
+ *  XForms is distributed in the hope that it will be useful, but
+ *  WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Lesser General Public License for more details.
  *
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with XForms; see the file COPYING.  If not, write to
+ *  the Free Software Foundation, 59 Temple Place - Suite 330, Boston,
+ *  MA 02111-1307, USA.
  */
 
 
@@ -48,6 +46,9 @@ FL_OBJECT *chartobj,
 static void create_form_form(void);
 
 
+/***************************************
+ ***************************************/
+
 static void
 set_function( FL_OBJECT * obj  FL_UNUSED_ARG,
 			  long        arg )
@@ -58,66 +59,84 @@ set_function( FL_OBJECT * obj  FL_UNUSED_ARG,
 }
 
 
+/***************************************
+ ***************************************/
+
 static void
 set_step( FL_OBJECT * obj  FL_UNUSED_ARG,
 		  long        arg  FL_UNUSED_ARG )
 {
-     step = fl_get_slider_value( stepobj );
+	step = fl_get_slider_value( stepobj );
 }
 
 
+/***************************************
+ ***************************************/
+
 static double
 next_step( void )
 {
-   double res = 0.0;
+	double res = 0.0;
 
-   switch ( func)
-   {
-	   case 1:
-		   res = sin( x );
-		   break;
+	switch ( func)
+	{
+		case 1:
+			res = sin( x );
+			break;
 
-	   case 2:
-		   res = sin( 2 * x ) * cos( x );
-		   break;
+		case 2:
+			res = sin( 2 * x ) * cos( x );
+			break;
 
-	   case 3:
-		   res = sin( 2 * x ) + cos( x );
-		   break;
+		case 3:
+			res = sin( 2 * x ) + cos( x );
+			break;
 
-	   case 4:
-		   res = sin( 3 * x ) + cos( x );
-		   break;
+		case 4:
+			res = sin( 3 * x ) + cos( x );
+			break;
 
-	   case 5:
-		   res = sin( x ) * sin( x ) + cos( x );
-		   break;
+		case 5:
+			res = sin( x ) * sin( x ) + cos( x );
+			break;
 
-	   case 6:
-		   res = sin( x ) * sin( x ) * sin( x );
-		   break;
+		case 6:
+			res = sin( x ) * sin( x ) * sin( x );
+			break;
     }
 
     x += 0.2 * step;
+
     return res;
 }
 
 
-int idle_cb( XEvent * xev  FL_UNUSED_ARG,
-			 void   * d    FL_UNUSED_ARG )
+/***************************************
+ ***************************************/
+
+int
+idle_cb( XEvent * xev  FL_UNUSED_ARG,
+		 void   * d    FL_UNUSED_ARG )
 {
-    fl_insert_chart_value( chartobj,1,next_step( ), "", 1 );
+    fl_insert_chart_value( chartobj, 1, next_step( ), "", 1 );
     return 0;
 }
 
 
-void add_value( void * xev  FL_UNUSED_ARG,
-				void * a    FL_UNUSED_ARG )
+/***************************************
+ ***************************************/
+
+void
+add_value( void * xev  FL_UNUSED_ARG,
+		   void * a    FL_UNUSED_ARG )
 {
 	fl_insert_chart_value( chartobj, 1, next_step( ), "", 1 );
 }
 
 
+/***************************************
+ ***************************************/
+
 int
 main( int    argc,
 	  char * argv[ ] )
@@ -148,6 +167,9 @@ main( int    argc,
 }
 
 
+/***************************************
+ ***************************************/
+
 static void
 create_form_form( void )
 {
