@@ -1,22 +1,20 @@
 /*
+ *  This file is part of XForms.
  *
- * This file is part of XForms.
+ *  XForms is free software; you can redistribute it and/or modify it
+ *  under the terms of the GNU Lesser General Public License as
+ *  published by the Free Software Foundation; either version 2.1, or
+ *  (at your option) any later version.
  *
- * XForms is free software; you can redistribute it and/or modify it
- * under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation; either version 2.1, or
- * (at your option) any later version.
- *
- * XForms is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with XForms; see the file COPYING.  If not, write to
- * the Free Software Foundation, 59 Temple Place - Suite 330, Boston,
- * MA 02111-1307, USA.
+ *  XForms is distributed in the hope that it will be useful, but
+ *  WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Lesser General Public License for more details.
  *
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with XForms; see the file COPYING.  If not, write to
+ *  the Free Software Foundation, 59 Temple Place - Suite 330, Boston,
+ *  MA 02111-1307, USA.
  */
 
 
@@ -27,10 +25,9 @@
  * the shared library (It it in the static library). You can compile
  * ../FORMS/gl.c and put it in the shared library if you have mesa/OpenGL
  *
- *   Also you might want to make a link libGL.a to libMesaGL.a
- *
- *  T.C. Zhao and M. Overmars
+ * Also you might want to make a link libGL.a to libMesaGL.a
  *
+ * T.C. Zhao and M. Overmars
  */
 
 #ifdef HAVE_CONFIG_H
@@ -64,50 +61,59 @@ static int prim = GL_POLYGON ;
 #define v3f glVertex3f
 
 
-static void draw_cube( void )
+/***************************************
+ ***************************************/
+
+static
+void draw_cube( void )
 {
 	glColor3f( 1.0, 0.0, 0.0 );
 	glBegin( prim );
 	v3f( 1.0, 1.0, 1.0 );   v3f( 1.0, -1.0, 1.0 );
 	v3f( 1.0, -1.0, -1.0 ); v3f( 1.0, 1.0, -1.0 );
-	glEnd();
+	glEnd( );
 
 	glBegin( prim );
 	v3f( -1.0, 1.0, 1.0 );   v3f( -1.0, 1.0, -1.0 );
 	v3f( -1.0, -1.0, -1.0 ); v3f( -1.0, -1.0, 1.0 );
-	glEnd();
+	glEnd( );
 
 	glColor3f( 0.0, 1.0, 0.0 );
 	glBegin( prim );
 	v3f(  1.0, 1.0,  1.0 ); v3f(  1.0, 1.0, -1.0 );
 	v3f( -1.0, 1.0, -1.0 ); v3f( -1.0, 1.0,  1.0 );
-	glEnd();
+	glEnd( );
 
 	glBegin( prim );
 	v3f(  1.0, -1.0,  1.0 ); v3f( -1.0, -1.0,  1.0 );
 	v3f( -1.0, -1.0, -1.0 ); v3f(  1.0, -1.0, -1.0 );
-	glEnd();
+	glEnd( );
 
 	glColor3f( 0.0, 0.0, 1.0 );
 	glBegin( prim );
 	v3f(  1.0,  1.0,  1.0 ); v3f( -1.0,  1.0,  1.0 );
 	v3f( -1.0, -1.0,  1.0 ); v3f(  1.0, -1.0,  1.0 );
-	glEnd();
+	glEnd( );
 
 	glBegin( prim );
 	v3f(  1.0, 1.0, -1.0 ); v3f(  1.0,-1.0, -1.0 );
 	v3f( -1.0,-1.0, -1.0 ); v3f( -1.0, 1.0, -1.0 );
-	glEnd();
+	glEnd( );
 }
 
 
+/***************************************
+ ***************************************/
+
 int
 idle_cb( XEvent * ev,
 		 void   * data  FL_UNUSED_ARG )
 {
-    static GLfloat xrot, yrot, zrot;
+    static GLfloat xrot,
+		           yrot,
+		           zrot;
 
-    if( ! ui->form->visible  || ! ui->canvas->visible )
+    if ( ! ui->form->visible  || ! ui->canvas->visible )
 		return 0;
 
     fl_activate_glcanvas(ui->canvas);
@@ -140,6 +146,9 @@ idle_cb( XEvent * ev,
 }
 
 
+/***************************************
+ ***************************************/
+
 int
 canvas_expose( FL_OBJECT * ob   FL_UNUSED_ARG,
 			   Window      win  FL_UNUSED_ARG,
@@ -170,6 +179,9 @@ canvas_expose( FL_OBJECT * ob   FL_UNUSED_ARG,
 }
 
 
+/***************************************
+ ***************************************/
+
 int
 buttonpress_cb( FL_OBJECT * ob   FL_UNUSED_ARG,
 				Window      win  FL_UNUSED_ARG,
@@ -187,6 +199,9 @@ buttonpress_cb( FL_OBJECT * ob   FL_UNUSED_ARG,
 }
 
 
+/***************************************
+ ***************************************/
+
 void
 switch_primitive( FL_OBJECT * ob    FL_UNUSED_ARG,
 				  long        data  FL_UNUSED_ARG )
@@ -219,6 +234,9 @@ static int dbuf[ ]= { GLX_RGBA,
 					  None};
 
 
+/***************************************
+ ***************************************/
+
 void
 buffer_cb( FL_OBJECT * ob,
 		   long        data  FL_UNUSED_ARG )
@@ -232,6 +250,9 @@ buffer_cb( FL_OBJECT * ob,
 }
 
 
+/***************************************
+ ***************************************/
+
 void
 menu_cb( FL_OBJECT * ob    FL_UNUSED_ARG,
 		 long        data  FL_UNUSED_ARG )
@@ -239,6 +260,9 @@ menu_cb( FL_OBJECT * ob    FL_UNUSED_ARG,
 }
 
 
+/***************************************
+ ***************************************/
+
 int main( int    argc,
 		  char * argv[ ] )
 {
@@ -272,6 +296,9 @@ int main( int    argc,
 }
 
 
+/***************************************
+ ***************************************/
+
 static void
 hide_it( FL_OBJECT * ob,
 		 long        data  FL_UNUSED_ARG )
@@ -289,6 +316,9 @@ hide_it( FL_OBJECT * ob,
 }
 
 
+/***************************************
+ ***************************************/
+
 static void
 reshow( FL_OBJECT * ob,
 		long        data  FL_UNUSED_ARG )
@@ -302,7 +332,11 @@ reshow( FL_OBJECT * ob,
 #include <stdlib.h>
 
 
-FD_form * create_form_form( void )
+/***************************************
+ ***************************************/
+
+FD_form *
+create_form_form( void )
 {
 	FL_OBJECT *obj;
 	FD_form *fdui = fl_calloc( 1, sizeof *fdui);
